@@ -16,8 +16,7 @@
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Street #330, Boston, MA 02111-1307, USA.
+ *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 #include <config.h>
@@ -31,12 +30,12 @@
 #include "file-utils.h"
 #include "fr-stock.h"
 #include "fr-window.h"
-#include "gconf-utils.h"
 #include "gtk-utils.h"
 #include "preferences.h"
 
 typedef struct {
 	FrWindow    *window;
+	GSettings   *settings;
 	GtkWidget   *dialog;
 	GtkWidget   *include_subfold_checkbutton;
 	GtkWidget   *add_if_newer_checkbutton;
@@ -59,6 +58,7 @@ static void
 open_file_destroy_cb (GtkWidget  *widget,
 		      DialogData *data)
 {
+	g_object_unref (data->settings);
 	g_free (data->last_options);
 	g_free (data);
 }
@@ -185,7 +185,7 @@ include_subfold_toggled_cb (GtkWidget *widget,
 	DialogData *data = callback_data;
 
 	gtk_widget_set_sensitive (data->exclude_symlinks,
-				  GTK_TOGGLE_BUTTON (widget)->active);
+				  gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (widget)));
 
 	return FALSE;
 }
@@ -210,9 +210,8 @@ add_folder_cb (GtkWidget *widget,
 	GtkWidget   *align;
 
 	data = g_new0 (DialogData, 1);
-
+	data->settings = g_settings_new (FILE_ROLLER_SCHEMA_ADD);
 	data->window = callback_data;
-
 	data->dialog = file_sel =
 		gtk_file_chooser_dialog_new (_("Add a Folder"),
 					     GTK_WINDOW (data->window),
@@ -444,7 +443,7 @@ dlg_add_folder_load_options (DialogData *data,
 	gboolean   recursive;
 	gboolean   no_symlinks;
 
-	options_dir = get_home_relative_file (RC_OPTIONS_DIR);
+	options_dir = get_user_config_subdirectory (ADD_FOLDER_OPTIONS_DIR, TRUE);
 	options_file = g_file_get_child (options_dir, name);
 	file_path = g_file_get_path (options_file);
 	key_file = g_key_file_new ();
@@ -505,14 +504,14 @@ dlg_add_folder_load_last_options (DialogData *data)
 	gboolean  recursive;
 	gboolean  no_symlinks;
 
-	base_dir = eel_gconf_get_string (PREF_ADD_CURRENT_FOLDER, "");
-	filename = eel_gconf_get_string (PREF_ADD_FILENAME, "");
-	include_files = eel_gconf_get_string (PREF_ADD_INCLUDE_FILES, "");
-	exclude_files = eel_gconf_get_string (PREF_ADD_EXCLUDE_FILES, "");
-	exclude_folders = eel_gconf_get_string (PREF_ADD_EXCLUDE_FOLDERS, "");
-	update = eel_gconf_get_boolean (PREF_ADD_UPDATE, FALSE);
-	recursive = eel_gconf_get_boolean (PREF_ADD_RECURSIVE, TRUE);
-	no_symlinks = eel_gconf_get_boolean (PREF_ADD_NO_SYMLINKS, FALSE);
+	base_dir = g_settings_get_string (data->settings, PREF_ADD_CURRENT_FOLDER);
+	filename = g_settings_get_string (data->settings, PREF_ADD_FILENAME);
+	include_files = g_settings_get_string (data->settings, PREF_ADD_INCLUDE_FILES);
+	exclude_files = g_settings_get_string (data->settings, PREF_ADD_EXCLUDE_FILES);
+	exclude_folders = g_settings_get_string (data->settings, PREF_ADD_EXCLUDE_FOLDERS);
+	update = g_settings_get_boolean (data->settings, PREF_ADD_UPDATE);
+	recursive = g_settings_get_boolean (data->settings, PREF_ADD_RECURSIVE);
+	no_symlinks = g_settings_get_boolean (data->settings, PREF_ADD_NO_SYMLINKS);
 
 	sync_widgets_with_options (data,
 			   	   base_dir,
@@ -629,14 +628,14 @@ dlg_add_folder_save_last_options (DialogData *data)
 				  &recursive,
 				  &no_symlinks);
 
-	eel_gconf_set_string (PREF_ADD_CURRENT_FOLDER, base_dir);
-	eel_gconf_set_string (PREF_ADD_FILENAME, filename);
-	eel_gconf_set_string (PREF_ADD_INCLUDE_FILES, include_files);
-	eel_gconf_set_string (PREF_ADD_EXCLUDE_FILES, exclude_files);
-	eel_gconf_set_string (PREF_ADD_EXCLUDE_FOLDERS, exclude_folders);
-	eel_gconf_set_boolean (PREF_ADD_UPDATE, update);
-	eel_gconf_set_boolean (PREF_ADD_RECURSIVE, recursive);
-	eel_gconf_set_boolean (PREF_ADD_NO_SYMLINKS, no_symlinks);
+	g_settings_set_string (data->settings, PREF_ADD_CURRENT_FOLDER, base_dir);
+	g_settings_set_string (data->settings, PREF_ADD_FILENAME, filename);
+	g_settings_set_string (data->settings, PREF_ADD_INCLUDE_FILES, include_files);
+	g_settings_set_string (data->settings, PREF_ADD_EXCLUDE_FILES, exclude_files);
+	g_settings_set_string (data->settings, PREF_ADD_EXCLUDE_FOLDERS, exclude_folders);
+	g_settings_set_boolean (data->settings, PREF_ADD_UPDATE, update);
+	g_settings_set_boolean (data->settings, PREF_ADD_RECURSIVE, recursive);
+	g_settings_set_boolean (data->settings, PREF_ADD_NO_SYMLINKS, no_symlinks);
 
 	g_free (base_dir);
 	g_free (filename);
@@ -705,7 +704,7 @@ aod_update_option_list (LoadOptionsDialogData *aod_data)
 
 	gtk_list_store_clear (list_store);
 
-	options_dir = get_home_relative_file (RC_OPTIONS_DIR);
+	options_dir = get_user_config_subdirectory (ADD_FOLDER_OPTIONS_DIR, TRUE);
 	make_directory_tree (options_dir, 0700, NULL);
 
 	file_enum = g_file_enumerate_children (options_dir, G_FILE_ATTRIBUTE_STANDARD_NAME, 0, NULL, &err);
@@ -767,7 +766,7 @@ aod_remove_cb (GtkWidget             *widget,
 	gtk_tree_model_get (aod_data->aod_model, &iter, 1, &filename, -1);
 	gtk_list_store_remove (GTK_LIST_STORE (aod_data->aod_model), &iter);
 
-	options_dir = get_home_relative_file (RC_OPTIONS_DIR);
+	options_dir = get_user_config_subdirectory (ADD_FOLDER_OPTIONS_DIR, TRUE);
 	options_file = g_file_get_child (options_dir, filename);
 	if (! g_file_delete (options_file, NULL, &error)) {
 		g_warning ("could not delete the options: %s", error->message);
@@ -874,7 +873,7 @@ save_options_cb (GtkWidget  *w,
 	GFile *options_file;
 	char  *opt_filename;
 
-	options_dir = get_home_relative_file (RC_OPTIONS_DIR);
+	options_dir = get_user_config_subdirectory (ADD_FOLDER_OPTIONS_DIR, TRUE);
 	make_directory_tree (options_dir, 0700, NULL);
 
 	opt_filename = _gtk_request_dialog_run (
