@@ -16,8 +16,7 @@
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Street #330, Boston, MA 02111-1307, USA.
+ *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 #include <config.h>
@@ -27,7 +26,7 @@
 #include <gtk/gtk.h>
 #include "dlg-package-installer.h"
 #include "gtk-utils.h"
-#include "main.h"
+#include "fr-init.h"
 
 
 typedef struct {
@@ -60,7 +59,7 @@ package_installer_terminated (InstallerData   *idata,
 
 	if (error_type != FR_PROC_ERROR_NONE) {
 		fr_archive_action_completed (idata->archive,
-					     FR_ACTION_CREATING_NEW_ARCHIVE,
+					     idata->action,
 					     error_type,
 					     error_message);
 	}
@@ -301,7 +300,7 @@ dlg_package_installer (FrWindow  *window,
 
 #else /* ! ENABLE_PACKAGEKIT */
 
-	package_installer_terminated (idata, _("Archive type not supported."));
+	package_installer_terminated (idata, FR_PROC_ERROR_GENERIC, _("Archive type not supported."));
 
 #endif /* ENABLE_PACKAGEKIT */
 }
